==> mega-linter-runner-7.3.1-beta202308241939.0.tgz: package/lib/ascii.js <==
function asciiArt() {
  return `
    .:oool'                                  ,looo;                           
    .xNXNXl                                 .dXNNXo.                          
     lXXXX0c.                              'oKXXN0;                           
     .oKNXNX0kxdddddddoc,.    .;lodddddddxk0XXXX0c                            
      .:kKXXXXXXXXXXXXNXX0dllx0XXXXXXXXXXXXXXXKd,                             
        .,cdkOOOOOOOO0KXXXXXXXXXXK0OOOOOOOkxo:'                               
                      'ckKXNNNXkc'                                            
              ':::::;.  .c0XX0l.  .;::::;.                                    
              'xXXXXXx'   :kx:   ;OXXXXKd.                                    
               .dKNNXXO;   ..   :0XXXXKl.                                     
                .lKXXXX0:     .lKXXXX0:                                       
                  :0XXXXKl.  .dXXXXXk,                                        
                   ;kXXXXKd:cxXXXXXx'                                         
                    'xXNXXXXXXXXXKo.                                          
                     .oKXXXXNXXX0l.                                           
                      .lKNNXNNXO:                                             
                        ,looool'                                              

==========================================================
=============   MegaLinter, by OX Security   =============
=========  https://ox.security?ref=megalinter  ===========
==========================================================
`;
}

function asciiArtCodeTotal() {
  return `
    .:oool'                                  ,looo;                           
    .xNXNXl                                 .dXNNXo.                          
     lXXXX0c.                              'oKXXN0;                           
     .oKNXNX0kxdddddddoc,.    .;lodddddddxk0XXXX0c                            
      .:kKXXXXXXXXXXXXNXX0dllx0XXXXXXXXXXXXXXXKd,                             
        .,cdkOOOOOOOO0KXXXXXXXXXXK0OOOOOOOkxo:'                               
                      'ckKXNNNXkc'                                            
              ':::::;.  .c0XX0l.  .;::::;.                                    
              'xXXXXXx'   :kx:   ;OXXXXKd.                                    
               .dKNNXXO;   ..   :0XXXXKl.                                     
                .lKXXXX0:     .lKXXXX0:                                       
                  :0XXXXKl.  .dXXXXXk,                                        
                   ;kXXXXKd:cxXXXXXx'                                         
                    'xXNXXXXXXXXXKo.                                          
                     .oKXXXXNXXX0l.                                           
                      .lKNNXNNXO:                                             
                        ,looool'                                              

==========================================================
=============   CodeTotal, by OX Security   ==============
=============     https://codetotal.io     ===============
==========================================================
`;
}

module.exports = { asciiArt, asciiArtCodeTotal };

==> mega-linter-runner-7.11.2-beta202405200524.0.tgz: package/lib/ascii.js <==
export function asciiArt() {
  return `
    .:oool'                                  ,looo;                           
    .xNXNXl                                 .dXNNXo.                          
     lXXXX0c.                              'oKXXN0;                           
     .oKNXNX0kxdddddddoc,.    .;lodddddddxk0XXXX0c                            
      .:kKXXXXXXXXXXXXNXX0dllx0XXXXXXXXXXXXXXXKd,                             
        .,cdkOOOOOOOO0KXXXXXXXXXXK0OOOOOOOkxo:'                               
                      'ckKXNNNXkc'                                            
              ':::::;.  .c0XX0l.  .;::::;.                                    
              'xXXXXXx'   :kx:   ;OXXXXKd.                                    
               .dKNNXXO;   ..   :0XXXXKl.                                     
                .lKXXXX0:     .lKXXXX0:                                       
                  :0XXXXKl.  .dXXXXXk,                                        
                   ;kXXXXKd:cxXXXXXx'                                         
                    'xXNXXXXXXXXXKo.                                          
                     .oKXXXXNXXX0l.                                           
                      .lKNNXNNXO:                                             
                        ,looool'                                              

==========================================================
=============   MegaLinter, by OX Security   =============
=========  https://ox.security?ref=megalinter  ===========
==========================================================
`;
}

export function asciiArtCodeTotal() {
  return `
    .:oool'                                  ,looo;                           
    .xNXNXl                                 .dXNNXo.                          
     lXXXX0c.                              'oKXXN0;                           
     .oKNXNX0kxdddddddoc,.    .;lodddddddxk0XXXX0c                            
      .:kKXXXXXXXXXXXXNXX0dllx0XXXXXXXXXXXXXXXKd,                             
        .,cdkOOOOOOOO0KXXXXXXXXXXK0OOOOOOOkxo:'                               
                      'ckKXNNNXkc'                                            
              ':::::;.  .c0XX0l.  .;::::;.                                    
              'xXXXXXx'   :kx:   ;OXXXXKd.                                    
               .dKNNXXO;   ..   :0XXXXKl.                                     
                .lKXXXX0:     .lKXXXX0:                                       
                  :0XXXXKl.  .dXXXXXk,                                        
                   ;kXXXXKd:cxXXXXXx'                                         
                    'xXNXXXXXXXXXKo.                                          
                     .oKXXXXNXXX0l.                                           
                      .lKNNXNNXO:                                             
                        ,looool'                                              

==========================================================
=============   CodeTotal, by OX Security   ==============
=============     https://codetotal.io     ===============
==========================================================
`;
}
